@@ -20,7 +20,7 @@ class Riyugo(Depot):
         }
         response = requests.post('https://4ae.cn/localup.php', data=data, files=files)
         if response.status_code != 200:
-            return self._set_error('upload fail')
+            return self._set_error(f'upload fail. code: {response.status_code}. content: {response.text}')
         data = response.json()
         if data.get('result') != 'success' or not data.get('url'):
             return self._set_error(response.text)
