@@ -19,12 +19,14 @@ class DepotType(Enum):
     """
     Riyugo = auto()
     """
-    链接存在有效期
-    
+    限制: 
+        1. 图片3天内有效
     url: https://riyugo.com/
     """
     NiuPic = auto()
     """
+    牛客网
+    
     url: https://www.niupic.com/
     """
     ImgUrl = auto()
@@ -49,6 +51,33 @@ class DepotType(Enum):
         1. 图片链接空 referer 访问时, 会重定向到图床网址
     url: https://imgbb.com/
     """
+    Xywm = auto()
+    """
+    图床
+        1. 注册用户存在限制, 可能登录后查看
+            * 限制并发数量及上传数量
+    
+    url: https://pic.xywm.ltd/
+    """
+    BoLuo = auto()
+    """
+    图床, 限制: 
+        1. 每天限制上传10张
+    url: https://www.boluo.link/
+    """
+    ImgAx = auto()
+    """
+    url: https://img.ax/
+    """
+    HuaBan = auto()
+    """
+    花瓣网站的图片上传. 图片上传接口在图集上传处发现
+    
+    限制: 
+        1. 需要先登录
+        2. 图片做了 referer 判断, 空 referer 可访问
+    url: https://huaban.com/
+    """
     Ai58 = auto()
     """
     58同城客服, 在线上传图片
@@ -57,5 +86,7 @@ class DepotType(Enum):
     """
     Github = auto()
     """
+    借用 github 仓库
+    
     url: https://github.com
     """
